@@ -50,7 +50,8 @@ def read_sfh(byt_str):
             sfo.abase()
         elif typ == 14:
             sfo.qualifier()
-
+        elif typ == 18:
+            sfo.addrlen()
         sfhead[onam] = sfo
         sfhead['obj_nam'].append(onam)
         sfhead['obj_id'][onam] = j
@@ -199,3 +200,8 @@ class SFH_READ:
         self.data_format = unpack('>H' , self.val[ : 2])[0]
         self.num_dims, self.qsub_typ = unpack('>2H' , self.val[4: 8])
         self.index_4, self.index_3, self.index_2, self.max_sections = unpack('>4I' , self.val[8: 24])
+
+
+    def addrlen(self):
+
+        self.addrlen = unpack('>H' , self.val[ : 2])[0]
