@@ -231,9 +231,9 @@ class SFREAD:
             logger.error('Shotfile %s not found' %self.sfile)
             return
 
-        if self.status:
-            self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
-            self.parsets = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [3, 4] ]
+        logger.info('Fetching SF %s', self.sfile)
+        self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
+        self.parsets = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [3, 4] ]
         if 'ADDRLEN' in self.sfh.keys():
             size_fac = sfdics.addrsizes[self.sfh['ADDRLEN'].addrlen]
             for obj in self.sfh.keys():
@@ -370,23 +370,10 @@ class SFREAD:
                 dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
 # Calibrated signals and signal groups
-            if otyp in (6, 7) and cal:
-                pscal = self.lincalib(obj)
-                if pscal is not None:
-                    for j in range(10):
-                        mult = 'MULTIA0%d' %j
-                        shif = 'SHIFTB0%d' %j
-                        if mult in pscal.keys():
-# we need to fix the content of pscal for signagroups
-# assuming first entry wins
-                            if (pscal[mult].size > 1):
-                                pscal[mult] = pscal[mult][0]
-                                pscal[shif] = pscal[shif][0]
-                            dout = dout * pscal[mult] + pscal[shif]
-                        else:
-                            break
-                    if self.diag in ('DCN', 'DCK', 'DCR'):
-                        dout.phys_unit = '1/m^2'
+            if cal:
+                dout = self.raw2calib(dout)
+                if self.diag in ('DCN', 'DCK', 'DCR'):
+                    dout.phys_unit = '1/m^2'
  
         return dout
 
@@ -425,6 +412,33 @@ class SFREAD:
         return None
 
 
+    def raw2calib(self, data):
+
+# Calibrated signals and signal groups
+        obj = str_byt.to_str(data.objnam)
+        if data.obj_type not in (6, 7):
+            logging.error('Calibration failed for %s: no Sig, no SGR', obj)
+            return data
+        pscal = self.lincalib(obj)
+        if pscal is not None:
+            for j in range(10):
+                mult = 'MULTIA0%d' %j
+                shif = 'SHIFTB0%d' %j
+                if mult in pscal.keys():
+# we need to fix the content of pscal for signagroups
+# assuming first entry wins
+                    if j == 0:
+                        dout = data*1. # Creates a copy of a read-only array, only once
+                    if (pscal[mult].size > 1):
+                        pscal[mult] = pscal[mult][0]
+                        pscal[shif] = pscal[shif][0]
+                    dout *= pscal[mult]
+                    dout += pscal[shif]
+                else:
+                    break
+        return dout
+
+
     def lincalib(self, obj):
         """
         Returns coefficients for signal(group) calibration
