@@ -86,7 +86,7 @@ class WW:
             _space = ct.c_char_p( space )
 
             result = libddww.wwclose_(_error , self._diaref , _disp , _space , ldisp , lspace )
-            logger.info('Close: ', result, error.value, ' Edition', self.edition.value)
+            logger.info('Close: %d, Error: %d, Edition: %d', result, error.value, self.edition.value)
             if getError( error ):
                 raise Exception('ww: Error Closing Shotfile')
             del self._diaref
@@ -144,7 +144,7 @@ class WW:
 
 
     def SetObject(self, signame, data):
-        logger.info('Setting %s' %(signame))
+        logger.info('Setting %s', signame)
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
             otype = info['otype']
@@ -159,14 +159,15 @@ class WW:
     def SetSignal(self, signame, data, indices=None):
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(signame)
-            dtype = sfdics.fmt2typ[info['format']]
+            dfmt = info['format']
             otype = info['otype']
-            ctyp  = sfdics.typ2ct[dtype]
-            if dtype == 6:
-                lbuf = sfdics.fmt2len[info['format']]
+            if dfmt in sfdics.fmt2len.keys():
+                lbuf = sfdics.fmt2len[dfmt]
                 lsbuf = ct.c_uint64(lbuf)
+                sf_dtype = 6
             else:
                 lbuf = np.size(data)
+                sf_dtype = sfdics.fmt2typ[dfmt]
 
             signame = str_byt.to_byt(signame)
             lbl = sfdics.obj_name[otype]
@@ -177,14 +178,14 @@ class WW:
             clbuf   = ct.c_uint32(lbuf)
             stride  = ct.c_uint32(1)
             _error  = ct.byref(error)
-            _type   = ct.byref(ct.c_uint32(dtype))
+            _type   = ct.byref(ct.c_uint32(sf_dtype))
             _lbuf   = ct.byref(clbuf)
             _stride = ct.byref(stride)
             if indices is not None:
                 _indices = np.array(indices, dtype=np.int32).ctypes.data_as(ct.POINTER(ct.c_uint32))
 
-            if dtype == 6:
-                slen = sfdics.fmt2len[info['format']]
+            if dfmt in sfdics.fmt2len.keys():
+                slen = sfdics.fmt2len[dfmt]
 #                stride  = ct.c_uint32(slen)
                 stride  = ct.c_uint32(1)
                 _stride = ct.byref(stride)
@@ -209,8 +210,9 @@ class WW:
                              _error, self._diaref, name, _type, _lbuf, buffer, \
                              _stride, _indices, lname, lsbuf)
             else:
+                ctyp = sfdics.fmt2ct[dfmt]
                 data = np.atleast_1d(data)
-                data = np.array(data, dtype=sfdics.fmt2np[info['format']])
+                data = np.array(data, dtype=sfdics.fmt2np[dfmt])
                 if otype == 7:   # Signal
                     result = libddww.wwsignal_( \
                              _error, self._diaref, name, _type, _lbuf, \
@@ -232,14 +234,14 @@ class WW:
                 if getError( error ):
                     raise Exception('ww: Error Writing %s %s' %(lbl, sign) )
                 else:
-                    logger.info('Written %s %s' %(lbl, sign))
+                    logger.info('Written %s %s', lbl, sign)
 
 
     def SetSignalGroup(self, signame, data):
 
         info  = self._wwoinfo(signame)
-        dtype = sfdics.fmt2typ[info['format']]
-        if dtype == 6:
+        dfmt = info['format']
+        if dfmt in sfdics.fmt2len.keys():
             for i, dat in enumerate(data):
                 dat = dat.ljust(info['leng'])
                 indices = [i + 1, 1, 1]
@@ -257,7 +259,7 @@ class WW:
                     for j in range(data.shape[2]):
                         indices = [1 + i, 1 + j, 1]
                         self.SetSignal(signame, data[:, i, j], indices=indices)
-        logger.info('Written Signal Group %s' %signame)
+        logger.info('Written Signal Group %s', signame)
 
         return True
 
@@ -266,10 +268,13 @@ class WW:
 
         if hasattr(self, '_diaref'):
             info  = self._wwoinfo(areaname)
-            dtype = sfdics.fmt2typ[info['format']]
-            ctyp  = sfdics.typ2ct[dtype]
+            dfmt = info['format']
+            if dfmt in sfdics.fmt2len.keys():
+                raise Exception('AB cannot have string-like data')
+            sf_dtype = sfdics.fmt2typ[dfmt]
+            ctyp  = sfdics.fmt2ct[dfmt] # data have to be numerical for AB
 
-            data = np.array(data, dtype=sfdics.fmt2np[info['format']])
+            data = np.array(data, dtype=sfdics.fmt2np[dfmt])
             areaname = str_byt.to_byt(areaname)     
             sizes = (ct.c_uint32 * 3)()
             for jsiz in range(data.ndim):
@@ -281,7 +286,7 @@ class WW:
                     sizes[1] = sizes[2]
             else:
                 nt = 1
-            logger.debug(areaname, dtype, nt, data.shape, sizes[0:3])
+            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, sizes[:3])
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
             lname  = ct.c_uint64(len(areaname))
@@ -289,7 +294,7 @@ class WW:
             k2     = ct.c_long(nt)
             _k1    = ct.byref(k1)
             _k2    = ct.byref(k2)
-            _type  = ct.byref(ct.c_uint32(dtype))
+            _type  = ct.byref(ct.c_uint32(sf_dtype))
             _error = ct.byref(error)
             _sizes = ct.byref(sizes)
 
@@ -300,7 +305,7 @@ class WW:
             if getError(error):
                 raise Exception('ww.shotfile.SetAreabase: Error writing areabase %s' %areaname)
             else:
-                logger.info('Written Areabase %s' %areaname, sizes[0:3])
+                logger.info('Written Areabase %s, sizes %d %d %d', areaname, sizes[:3])
 
 
     def SetParameter(self, set_name, par_name, data):
@@ -310,32 +315,34 @@ class WW:
         """
         if hasattr(self, '_diaref'):
             info = self.GetParameterInfo(set_name, par_name)
-            dattype = sfdics.fmt2typ[info['format']]
-            ctyp  = sfdics.typ2ct[dattype]
+            dfmt = info['format']
+            if dfmt in sfdics.fmt2len.keys():
+                sf_dtype = 6
+            else:
+                sf_dtype = sfdics.fmt2typ[dfmt]
             set_name = str_byt.to_byt(set_name)
             par_name = str_byt.to_byt(par_name)
-            logger.info('PN %s' %par_name)
+            logger.info('PN %s', par_name)
             data = np.atleast_1d(data)
-            logger.debug('Data', data, dattype )
             ndata = len(data)
             nitem = info['items']
             if ndata > nitem:
-                logger.error('Too many %d entries for par_nam %s, more than in sfh %d' %(ndata, par_name, nitem))
+                logger.error('Too many %d entries for par_nam %s, more than in sfh %d', ndata, par_name, nitem)
                 return
             if ndata == 0:
-                logger.error('No data for par_nam %s' %par_name)
+                logger.error('No data for par_nam %s', par_name)
                 return
             if ndata < nitem:
-                data = np.zeros(nitem, dtype=sfdics.typ2np[dattype])
+                data = np.zeros(nitem, dtype=sfdics.typ2np[sf_dtype])
             error   = ct.c_int32(0)
             pset    = ct.c_char_p(set_name)
             par     = ct.c_char_p(par_name)
             lset    = ct.c_uint64(len(set_name))
             lpar    = ct.c_uint64(len(par_name))
-            _type   = ct.byref(ct.c_uint32(dattype))
+            _type   = ct.byref(ct.c_uint32(sf_dtype))
             _error  = ct.byref(error)
-            if dattype == 6:
-                slen = sfdics.fmt2len[info['format']]
+            if dfmt in sfdics.fmt2len.keys(): # string or string array
+                slen = sfdics.fmt2len[dfmt]
                 stride  = ct.c_uint32(1)
                 _stride = ct.byref(stride)
                 if type(data) == type('str'):
@@ -352,15 +359,16 @@ class WW:
                 buffer = ct.c_char_p(sbuf)
                 result = libddww.wwparm_(_error, self._diaref, pset, par, _type, _lbuf, \
                                          buffer, _stride, lset, lpar, lsbuf)
-            else:
-                datanp = np.array(data, dtype=sfdics.fmt2np[info['format']])
+            else: # numerical data
+                ctyp  = sfdics.fmt2ct[dfmt]
+                datanp = np.array(data, dtype=sfdics.fmt2np[dfmt])
                 if ndata < nitem:
                     datanp = np.append(datanp, np.zeros(nitem - ndata))
                 stride  = ct.c_uint32(1)
                 _stride = ct.byref(stride)
                 lbuf = ct.c_uint32(nitem)
                 _lbuf = ct.byref(lbuf)
-                if nitem == 1 and dattype == 5:
+                if nitem == 1 and sf_dtype == 5:
                     buffer = ctyp(datanp)
                 else:
                     buffer = ctyp.from_buffer(datanp)
@@ -371,7 +379,7 @@ class WW:
                 raise Exception('ww: Error Writing Parameters into %s -> %s' %(set_name.decode('utf-8'), par_name.decode('utf-8') ) )
 
             else:
-                logger.info('   PN %s' %par_name.decode('utf8'))
+                logger.info('   PN %s', par_name.decode('utf8'))
 
 
 def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
@@ -381,7 +389,7 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
     ww = WW()
 
     os.chdir(sfhdir)
-    logger.info(exp, diag, nshot)
+    logger.info('Exp: %s, diag: %s, nshot: %d', exp, diag, nshot)
     if not ww.Open(exp, diag, nshot):
         logger.error('Problems opening shotfile')
         return
@@ -399,7 +407,7 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
 
     for obj, data in data_d.items():
         if otype[obj] == 4:
-            logger.info('Writing PS %s' %obj)
+            logger.info('Writing PS %s', obj)
             for pn, pdata in data.items():
                 ww.SetParameter(obj, pn, pdata)
         if otype[obj] in (6, 7):
